@@ -384,6 +384,17 @@ class API:
         # fmt: off
         logging.info(self._selected_metrics[["metric", "unit_str", "site",
                                              "location"]])
+        if self._selected_metrics.empty:
+            raise E.DataSignalsError(
+                "\033[31;1mNo metrics found for the given query.\033[0m"
+                "\033[33;1m\nHINT:\033[22m Check \033[2msites\033[22m, "
+                "\033[2mlocations\033[22m, and \033[2mmetrics\033[22m "
+                "provided.\033[0m\n\n"
+                "Provided:\n"
+                f"• sites: {query.sites}\n"
+                f"• locations: {query.locations}\n"
+                f"• metrics: {query.metrics}\n"
+            )
         # fmt: on
         data_frames = []
         # Create groups based on metrics selection
@@ -732,6 +743,17 @@ class AsyncAPI(API):
         logging.info(
             self._selected_metrics[["metric", "unit_str", "site", "location"]]
         )
+        if self._selected_metrics.empty:
+            raise E.DataSignalsError(
+                "\033[31;1mNo metrics found for the given query.\033[0m"
+                "\033[33;1m\nHINT:\033[22m Check \033[2msites\033[22m, "
+                "\033[2mlocations\033[22m, and \033[2mmetrics\033[22m "
+                "provided.\033[0m\n\n"
+                "Provided:\n"
+                f"• sites: {query.sites}\n"
+                f"• locations: {query.locations}\n"
+                f"metrics: {query.metrics}\n"
+            )
         data_frames = []
 
         async def fetch_data(site, location, group):
@@ -797,7 +819,7 @@ class AsyncAPI(API):
                 else:
                     desc = f"API-24SEA get_data in {chunk_size}-sized chunks [total locations: {total_tasks}]"
                 for i in tqdm(
-                    range(0, len(tasks), chunk_size),
+                    range(0, len(tasks), max(1, chunk_size)),
                     desc=desc,
                     colour="#c9cfd8",
                 ):
@@ -839,7 +861,19 @@ class AsyncAPI(API):
         else:
             data_ = pd.concat([data_] + data_frames, ignore_index=True)
 
-        logging.info("\033[32;1m✔️ Data successfully retrieved.\033[0m")
+        if all(
+            getattr(r, "status_code", 200) == 200
+            for r in data_frames
+            if hasattr(r, "status_code")
+        ):
+            logging.info("\033[32;1m✔️ Data successfully retrieved.\033[0m")
+        else:
+            # If any response is not 200, return the response text(s)
+            return [
+                getattr(r, "text", "")
+                for r in data_frames
+                if hasattr(r, "status_code") and r.status_code != 200
+            ]
         data.drop(data.index, inplace=True)
         for col in data_.columns:
             if col in data.columns:
